@@ -14,11 +14,12 @@ setClass("Sline",
 )
 
 setClass("Slines",
-	representation("Spatial", Slines = "list"),
+	representation("Spatial", Slines = "list", ID = "character"),
 	prototype = list(bbox = matrix(rep(NA, 6), 3, 2, 
 			dimnames = list(NULL, c("min","max"))),
 		proj4string = CRS(as.character(NA)),
-		Slines = list()),
+		Slines = list(),
+		ID = as.character(NA)),
 	validity = function(object) {
 		if (any(sapply(object@Slines, function(x) !is(x, "Sline"))))
 			stop("not a list of Sline objects")
@@ -37,6 +38,9 @@ setClass("SpatialLines",
 		if (any(sapply(object@lines, function(x) 
 			!identical(proj4string(object), proj4string(x))))) 
 			stop("Different projections")
+		if (length(object@lines) != 
+			length(unique(getSLSlinesIDSlots(object)))) 
+				return("non-unique Slines ID slot values")
 		return(TRUE)
 	}
 )
@@ -44,6 +48,12 @@ setClass("SpatialLines",
 getSLlinesSlot <- function(SL) SL@lines
 
 getSlinesSlinesSlot <- function(SL) SL@Slines
-#getSlinesIDSlot function(SL) SL@ID
+
+getSlinesIDSlot <- function(Slines) Slines@ID
+
+getSLSlinesIDSlots <- function(SL) {
+	Sls <- getSLlinesSlot(SL)
+	sapply(Sls, getSlinesIDSlot)
+}
 
 
