@@ -112,7 +112,8 @@ sample.Sgrid = function(x, n, type = "random", bb = bbox(x),
 	#id = overlay(as(x, "SpatialGrid"), pts)
 	id = overlay(x, pts)
 	if (is(id, "SpatialPointsDataFrame"))
-		id = id@data[,1]
+		#id = id@data[,1]
+		id = id@data@att[[1]]
 	pts[which(!is.na(id))]
 }
 setMethod("spsample", signature(x = "SpatialGrid"), sample.Sgrid)
@@ -127,7 +128,7 @@ sample.Spixels = function(x, n, type = "random", bb = bbox(x),
 	#id = overlay(as(x, "SpatialGrid"), pts)
 	id = overlay(x, pts)
 	if (is(id, "SpatialPointsDataFrame"))
-		id = id@data[,1]
+		id = id@data@att[[1]]
 	pts[which(!is.na(id))]
 }
 setMethod("spsample", signature(x = "SpatialPixels"), sample.Spixels)
